==> react-native-digitcamera-1.2.41.tgz: package/src/Screens/ApprovedScreen.js <==
import {
  View,
  Text,
  StyleSheet,
  Alert,
  Platform,
  PermissionsAndroid,
  Image,
} from "react-native";
import React, { useState, useEffect } from "react";
import Header from "../Screens/Header";
import style from "../common/CommonStyle";
import Database from "../../../../Components/common/Database";
let realm = Database.getRealm();
var PIVechicleData = realm.objects("PIVechicleData");
const successbg = require("../common/Image/successbg.png");

import {
  DIGIT_PAYMENT_CANCEL_URL,
  DIGIT_PAYMENT_SUCCESS_URL,
  DIGIT_FEED_BACK_PAGE_URL,
} from "../Api/ApiUrls";

import { async } from "validate.js";
import { generatePaymentLink } from "../common/Services/generatePaymentLink";
import { downloadPdf } from "../common/Services/downloadPdf";
import { downloadFileToDevice } from "../common/commonFunctions";

const ApprovedScreen = ({ navigation, route }) => {
  const { data } = route.params;
  console.log("SSSSSSSS", data);
  useEffect(() => {
    showScreensBasedonConditions(data);
    // callGetActivityForAutoPIDecision();
  }, []);

  // const callGetActivityForAutoPIDecision = async () => {
  //   try {
  //     const data = await getActivityForAutoPIDecision({
  //       activityId: "91733011",
  //     });
  //     if (data != null || data.receivedActivities != null) {
  //       showTheScreensBasedOnAutoPIDecision(data);
  //     } else {
  //       Alert.alert("Something Went Wrong");
  //     }
  //   } catch (error) {
  //     console.log("Error in ", error);
  //   }
  // };

  // const showTheScreensBasedOnAutoPIDecision = (data) => {
  //   let isActivityApproved = data.receivedActivities.filter((item) => {
  //     if (item.key == "AutoPI-Decision") {
  //       return item;
  //     }
  //   });
  //   if (isActivityApproved[0]?.value == "Approved") {
  //     // if user PI is Approved
  //     //  handleVisibilityConditions("approve");
  //   } else {
  //     // if reinspection
  //   }
  // };

  const showScreensBasedonConditions = (data) => {
    try {
      if (data.policyNumber != null || data.policyNumber != "") {
        let PIReason = data?.additionalActivitiesList?.filter((item) => {
          if (item.key == "PI Reason") {
            return item;
          }
        });
        let breakin = data?.additionalActivitiesList?.filter((item) => {
          if (item.key == "breakin") {
            return item;
          }
        });

        if (PIReason[0]?.key == "PI Reason") {
          if (PIReason[0]?.value == "breakin") {
            let policyNumber = data?.policyNumber;
            showDownloadPolicyPDFScreen(policyNumber);
          } else {
            if (PIReason[0]?.value == "Endorsement") {
              // open web view use this urls
              let url =
                DIGIT_FEED_BACK_PAGE_URL +
                PIVechicleData[0]?.licensePlateNumber;
              Alert.alert(url);
              navigation.navigate("CustomWebview", { url: url });
            }
          }
        }
      }
    } catch (error) {
      console.log("Error in showScreensBasedonConditions()", error);
    }
  };

  const showDownloadPolicyPDFScreen = async (policyNumber) => {
    try {
      let body = {
        successReturnUrl: DIGIT_PAYMENT_SUCCESS_URL,
        applicationNumber: policyNumber,
        cancelReturnUrl: DIGIT_PAYMENT_CANCEL_URL,
      };
      console.log("BODY", body);
      const data = await generatePaymentLink({ body: body });
      let status = data.status;
      console.log("Payment service Status code :", status);
      if (status == 200) {
        // generate payment link
        if (data != null) {
          try {
            var paymentLink = data;
            // navigate to web view
            navigation.navigate("CustomWebview", { url: paymentLink });
          } catch (error) {
            console.log("Error in genrate Payment link", error);
          }
        }
      } else {
        if (status == 400) {
          // genrate PDF
          showPDFScreen(policyNumber);
        }
      }
    } catch (error) {
      console.log("Error in showDownloadPolicyPDFScreen", error);
    }
  };

  const showPDFScreen = async (policyNumber) => {
    try {
      if (Platform.OS === "android") {
        const grantedWrite = await PermissionsAndroid.request(
          PermissionsAndroid.PERMISSIONS.WRITE_EXTERNAL_STORAGE
        );
        const grantedRead = await PermissionsAndroid.request(
          PermissionsAndroid.PERMISSIONS.READ_EXTERNAL_STORAGE
        );
        if (
          grantedWrite !== PermissionsAndroid.RESULTS.GRANTED ||
          grantedRead !== PermissionsAndroid.RESULTS.GRANTED
        ) {
          Alert("Storage access denied");
          return;
        }
      }

      var body = {
        policyNumber: policyNumber,
      };
      const pdfData = await downloadPdf({ body: body });
      if (pdfData != null) {
        var pdfDownloadUrl = pdfData.quotePath;
        console.log("pdf url ", pdfDownloadUrl);
        let filename = `${policyNumber}.pdf`;
        console.log("^^^^^^^^", pdfDownloadUrl);
        downloadFileToDevice({ url: pdfDownloadUrl, filename });
      }
    } catch (error) {
      console.log("Error in showPDFScreen()", error);
    }
  };

  return (
    <View style={styles.ApprovedScreenContainer}>
      <Header hideArrowBackButton={true} shiftTitleToLeft={true} />
      <Image style={{ width: "100%", height: "35%" }} source={successbg} />
      <Text
        style={[
          style.muliExBoldDB,
          { fontSize: 20, textAlign: "center", marginTop: 20 },
        ]}
      >
        Yay! wasn't that quick?
      </Text>
      <Text
        style={[
          style.muliRegDB,
          { fontSize: 16, textAlign: "center", marginVertical: 8 },
        ]}
      >
        Your pre-inspection has been approved by Aria, out in-house bot.
      </Text>
    </View>
  );
};

export default ApprovedScreen;

const styles = StyleSheet.create({
  ApprovedScreenContainer: {
    flex: 1,
    backgroundColor: "white",
    justifyContent: "flex-start",
  },
});

==> react-native-digitcamera-1.2.42.tgz: package/src/Screens/ApprovedScreen.js <==
import {
  View,
  Text,
  StyleSheet,
  Alert,
  Platform,
  PermissionsAndroid,
  Image,
} from "react-native";
import React, { useState, useEffect } from "react";
import Header from "../Screens/Header";
import style from "../common/CommonStyle";
import Database from "../../../../Components/common/Database";
let realm = Database.getRealm();
var PIVechicleData = realm.objects("PIVechicleData");
const successbg = require("../common/Image/successbg.png");

import {
  DIGIT_PAYMENT_CANCEL_URL,
  DIGIT_PAYMENT_SUCCESS_URL,
  DIGIT_FEED_BACK_PAGE_URL,
} from "../Api/ApiUrls";

import { async } from "validate.js";
import { generatePaymentLink } from "../common/Services/generatePaymentLink";
import { downloadPdf } from "../common/Services/downloadPdf";
import { downloadFileToDevice } from "../common/commonFunctions";

const ApprovedScreen = ({ navigation, route }) => {
  const { data } = route.params;
  useEffect(() => {
    showScreensBasedonConditions(data);
    // callGetActivityForAutoPIDecision();
  }, []);

  // const callGetActivityForAutoPIDecision = async () => {
  //   try {
  //     const data = await getActivityForAutoPIDecision({
  //       activityId: "91733011",
  //     });
  //     if (data != null || data.receivedActivities != null) {
  //       showTheScreensBasedOnAutoPIDecision(data);
  //     } else {
  //       Alert.alert("Something Went Wrong");
  //     }
  //   } catch (error) {
  //     console.log("Error in ", error);
  //   }
  // };

  // const showTheScreensBasedOnAutoPIDecision = (data) => {
  //   let isActivityApproved = data.receivedActivities.filter((item) => {
  //     if (item.key == "AutoPI-Decision") {
  //       return item;
  //     }
  //   });
  //   if (isActivityApproved[0]?.value == "Approved") {
  //     // if user PI is Approved
  //     //  handleVisibilityConditions("approve");
  //   } else {
  //     // if reinspection
  //   }
  // };

  const showScreensBasedonConditions = (data) => {
    try {
      if (data.policyNumber != null || data.policyNumber != "") {
        let PIReason = data?.additionalActivitiesList?.filter((item) => {
          if (item.key == "PI Reason") {
            return item;
          }
        });
        let breakin = data?.additionalActivitiesList?.filter((item) => {
          if (item.key == "breakin") {
            return item;
          }
        });

        if (PIReason[0]?.key == "PI Reason") {
          if (PIReason[0]?.value == "breakin") {
            let policyNumber = data?.policyNumber;
            showDownloadPolicyPDFScreen(policyNumber);
          } else {
            if (PIReason[0]?.value == "Endorsement") {
              // open web view use this urls
              let url =
                DIGIT_FEED_BACK_PAGE_URL +
                PIVechicleData[0]?.licensePlateNumber;
              Alert.alert(url);
              navigation.navigate("CustomWebview", { url: url });
            }
          }
        }
      }
    } catch (error) {
      console.log("Error in showScreensBasedonConditions()", error);
    }
  };

  const showDownloadPolicyPDFScreen = async (policyNumber) => {
    try {
      let body = {
        successReturnUrl: DIGIT_PAYMENT_SUCCESS_URL,
        applicationNumber: policyNumber,
        cancelReturnUrl: DIGIT_PAYMENT_CANCEL_URL,
      };
      console.log("BODY", JSON.stringify(body));
      const data = await generatePaymentLink({ body: body });
      let status = data.status;
      console.log("Payment service Status code :", status);
      if (status == 200) {
        // generate payment link
        if (data != null) {
          try {
            var paymentLink = data;
            // navigate to web view
            navigation.navigate("CustomWebview", { url: paymentLink });
          } catch (error) {
            console.log("Error in genrate Payment link", error);
          }
        }
      } else {
        if (status == 400) {
          // genrate PDF
          showPDFScreen(policyNumber);
        }
      }
    } catch (error) {
      console.log("Error in showDownloadPolicyPDFScreen", error);
    }
  };

  const showPDFScreen = async (policyNumber) => {
    try {
      if (Platform.OS === "android") {
        const grantedWrite = await PermissionsAndroid.request(
          PermissionsAndroid.PERMISSIONS.WRITE_EXTERNAL_STORAGE
        );
        const grantedRead = await PermissionsAndroid.request(
          PermissionsAndroid.PERMISSIONS.READ_EXTERNAL_STORAGE
        );
        if (
          grantedWrite !== PermissionsAndroid.RESULTS.GRANTED ||
          grantedRead !== PermissionsAndroid.RESULTS.GRANTED
        ) {
          Alert("Storage access denied");
          return;
        }
      }

      var body = {
        policyNumber: policyNumber,
      };
      const pdfData = await downloadPdf({ body: body });
      if (pdfData != null) {
        var pdfDownloadUrl = pdfData.quotePath;
        console.log("pdf url ", pdfDownloadUrl);
        let filename = `${policyNumber}.pdf`;
        console.log("^^^^^^^^", pdfDownloadUrl);
        downloadFileToDevice({ url: pdfDownloadUrl, filename });
      }
    } catch (error) {
      console.log("Error in showPDFScreen()", error);
    }
  };

  return (
    <View style={styles.ApprovedScreenContainer}>
      <Header hideArrowBackButton={true} shiftTitleToLeft={true} />
      <Image style={{ width: "100%", height: "35%" }} source={successbg} />
      <Text
        style={[
          style.muliExBoldDB,
          { fontSize: 20, textAlign: "center", marginTop: 20 },
        ]}
      >
        Yay! wasn't that quick?
      </Text>
      <Text
        style={[
          style.muliRegDB,
          { fontSize: 16, textAlign: "center", marginVertical: 8 },
        ]}
      >
        Your pre-inspection has been approved by Aria, out in-house bot.
      </Text>
    </View>
  );
};

export default ApprovedScreen;

const styles = StyleSheet.create({
  ApprovedScreenContainer: {
    flex: 1,
    backgroundColor: "white",
    justifyContent: "flex-start",
  },
});
